/********************************************************************
	created:	2014/12/11
	created:	11:12:2014   19:24
	filename: 	CommonPlatform\Server\ServerInstance\CommonLib\Protocols\ProtoScene.cs
	file path:	CommonPlatform\Server\ServerInstance\CommonLib\Protocols
	file base:	ProtoScene
	file ext:	cs
	author:		刘冰生
	
	purpose:    Protocol for Login Module 
*********************************************************************/
using MongoDB.Bson.Serialization.Attributes;
using ProtoBuf;
using System;
using System.Collections.Generic;

namespace Protocols
{
    namespace gm
    {
        /// <summary>
        /// 后台登录
        /// </summary>
        [ProtoContract]
        public class BackLoginReq : ProtoBody
        {
            //账号
            [ProtoMember(1)] public string account = "";
            //密码
            [ProtoMember(2)] public string password = "";
        }

        /// <summary>
        /// 后台登录返回
        /// </summary>
        [ProtoContract]
        public class BackLoginRsp : ProtoBody
        {
            public enum ErrorID
            {
                //登录成功
                Success = 0,
                //登录失败
                Failed = 1,
                //没有权限
                NoPermission = 2,
                //密码不正确
                PasswordWrong = 3,
                //账号不存在
                AccountNotExist = 4,
            }

            [ProtoMember(1)] public ErrorID errorID = ErrorID.Failed;
            //账号ID
            [ProtoMember(2)] public ulong accountID = 0;
        }

        /// <summary>
        /// 后台注册
        /// </summary>
        [ProtoContract]
        public class BackRegisterReq : ProtoBody
        {
            //账号
            [ProtoMember(1)] public string account = "";
            //密码1
            [ProtoMember(2)] public string password1 = "";
            //密码2
            [ProtoMember(3)] public string password2 = "";
        }

        /// <summary>
        /// 后台注册返回
        /// </summary>
        [ProtoContract]
        public class BackRegisterRsp : ProtoBody
        {
            public enum ErrorID
            {
                //注册成功
                Success = 0,
                //注册失败
                Failed = 1,
                //密码不一致
                PasswordNotSame = 2,
                //账号已经存在
                AlreadyExist = 3,
                //不支持该账号注册
                NotValidAccount = 4,
            }

            [ProtoMember(1)] public ErrorID errorID = ErrorID.Failed;
        }

        /// <summary>
        /// token转换usdt比例
        /// </summary>
        [Serializable]
        [ProtoContract]
        public class GmToken2UsdtProportion
        {
            //玩家id
            [ProtoMember(1)] public float proportion = 0;
        }

        /// <summary>
        /// 用户信息
        /// </summary>
        [Serializable]
        [ProtoContract]
        public class GmUserInfo
        {
            //玩家id
            [ProtoMember(1)] public ulong userId = 0;

            //玩家名称
            [ProtoMember(2)] public string playerName = "";

            //持有token币
            [ProtoMember(3)] public float tokenCoin = 0;

            //持有游戏币
            [ProtoMember(4)] public float gameCoin = 0;

            //持有usdt币
            [ProtoMember(5)] public float usdtCoin = 0;
        }

        /// <summary>
        /// 玩家登录
        /// </summary>
        [Serializable]
        [ProtoContract]
        public class GmUserLogin
        {
            [ProtoMember(1)] public ulong accountId = 0;        //玩家id
            [ProtoMember(2)] public string playerName = "";     //玩家名称
            [ProtoMember(3)] public float tokenCoin = 0;        //持有token币
            [ProtoMember(4)] public float gameCoin = 0;         //持有游戏币
            [ProtoMember(5)] public float usdtCoin = 0;         //持有usdt币
            [ProtoMember(6)] public int olinePNums = 0;         //在线人数
        }

        /// <summary>
        /// 修改用户名称
        /// </summary>
        [Serializable]
        [ProtoContract]
        public class GmChangePlayerName
        {
            //玩家id
            [ProtoMember(1)] public ulong accountId = 0;
            //玩家名称
            [ProtoMember(2)] public string playerName = "";
        }

        /// <summary>
        /// 用户币变化
        /// </summary>
        [Serializable]
        [ProtoContract]
        public class GmPlayerCoinChange
        {
            //玩家id
            [ProtoMember(1)] public ulong accountId = 0;
            //币类型1 游戏币  2 make  3 usdt
            [ProtoMember(2)] public int coinType = 0;
            //币改变的值
            [ProtoMember(3)] public float coinChange = 0;
            //币数量
            [ProtoMember(4)] public float coinNums = 0;
        }

        public enum ECoinChange
        {
            gameCoin = 1,//游戏币
            makeCoin = 2,//make币
            usdtCoin = 3,//usdt币
        }

        /// <summary>
        /// 玩家日复投USDT
        /// </summary>
        [Serializable]
        [ProtoContract]
        public class GmPlayerDayReinvestUSDT
        {
            //玩家id
            [ProtoMember(1)] public ulong accountId = 0;

            //币改变的值
            [ProtoMember(2)] public long coinChange = 0;
        }

        /// <summary>
        /// 玩家日复投USDT 满额
        /// </summary>
        [Serializable]
        [ProtoContract]
        public class GmPlayerDayFullReinvestment
        {
            //玩家id
            [ProtoMember(1)] public ulong accountId = 0;
        }

        /// <summary>
        /// 玩家关卡分布
        /// </summary>
        [Serializable]
        [ProtoContract]
        public class GmPlayerLevelDistributed
        {
            //当前关卡
            [ProtoMember(1)] public int curLevel = 0;
        }

        /// <summary>
        /// 在线玩家数
        /// </summary>
        [Serializable]
        [ProtoContract]
        public class GmOnlinePNums
        {
            //在线玩家数
            [ProtoMember(1)] public long onlinePNums = 0;
        }

        /// <summary>
        /// 公告
        /// </summary>
        public class GmNotice
        {
            //中文
            public string contentChinese { get; set; }
            //英文
            public string contentEnglish { get; set; }
        }

        /// <summary>
        /// 弹框公告
        /// </summary>
        public class GmEjectNotice
        {
            public string contentChinese { get; set; }
            public string contentEnglish { get; set; }

            public ulong date { get; set; }

            public string titleChinese { get; set; }

            public string titleEnglish { get; set; }
        }

        /// <summary>
        /// 玩家状态
        /// </summary>
        public class GmChangePlayerState
        {
            //玩家账号
            public ulong accountId { get; set; }
            //玩家状态
            public int state { get; set; }
        }

        ///// <summary>
        ///// 被踢下线
        ///// </summary>
        //[ProtoContract]
        //public class PlayerKickTheLineNtf : ProtoBody
        //{

        //}

        #region 后台银行相关
        /// <summary>
        /// 获取银行利率列表
        /// </summary>
        [Serializable]
        [ProtoContract]
        public class GMGetBankRates
        {
            /// <summary>
            /// 利率列表
            /// </summary>
            [ProtoMember(1)] public List<GMBankRate> rows = new List<GMBankRate>();

            /// <summary>
            /// 消息ID
            /// </summary>
            [ProtoMember(2)] public int msgType = 0;
        }

        /// <summary>
        /// 银行利率条目
        /// </summary>
        [Serializable]
        [ProtoContract]
        public class GMBankRate
        {
            [ProtoMember(1)] public uint id = 0;

            /// <summary>
            /// 月份
            /// </summary>
            [ProtoMember(2)] public int month = 0;

            /// <summary>
            /// 利率
            /// </summary>
            [ProtoMember(3)] public float rateOf = 0;

            /// <summary>
            /// 是否在使用 0-未使用 1-使用
            /// </summary>
            [ProtoMember(4)] public int isUse = 0;
        }

        /// <summary>
        /// 银行存款
        /// </summary>
        [Serializable]
        [ProtoContract]
        public class GMBankSaveMoney
        {
            [ProtoMember(1)] public string userId = "";

            [ProtoMember(2)] public uint rateOfId = 0;

            [ProtoMember(3)] public double amountDeposited = 0;
        }

        /// <summary>
        /// 银行存款返回
        /// </summary>
        [Serializable]
        [ProtoContract]
        public class GMBankSaveMoneyRsp
        {
            [ProtoMember(1)] public string msg = "";

            [ProtoMember(2)] public int code = 0;

            [ProtoMember(3)] public GMBankSaveMoneyData data = new GMBankSaveMoneyData();
        }

        /// <summary>
        /// 银行存款返回数据
        /// </summary>
        [Serializable]
        [ProtoContract]
        public class GMBankSaveMoneyData
        {
            [ProtoMember(1)] public ulong bankId = 0;

            [ProtoMember(2)] public uint rateOfId = 0;

            [ProtoMember(3)] public double amountDeposited = 0;

            [ProtoMember(4)] public string createTime = "";

            [ProtoMember(5)] public string endTime = "";
        }

        /// <summary>
        /// 银行取款
        /// </summary>
        [Serializable]
        [ProtoContract]
        public class GMBankDrawMoney
        {
            [ProtoMember(1)] public string userId = "";

            [ProtoMember(2)] public ulong bankId = 0;
        }

        /// <summary>
        /// 银行取款返回
        /// </summary>
        [Serializable]
        [ProtoContract]
        public class GMBankDrawMoneyRsp
        {
            [ProtoMember(1)] public string msg = "";

            [ProtoMember(2)] public int code = 0;

            [ProtoMember(3)] public GMBankDrawMoneyData data = new GMBankDrawMoneyData();
        }

        [Serializable]
        [ProtoContract]
        public class GMBankDrawMoneyData
        {
            [ProtoMember(1)] public ulong bankId = 0;

            [ProtoMember(2)] public uint rateOfId = 0;

            [ProtoMember(3)] public double amountDeposited = 0;

            [ProtoMember(4)] public double balance = 0;

            [ProtoMember(5)] public string createTime = "";
        }

        #endregion

        #region 后台交易所相关

        /// <summary>
        /// 交易所网络通信
        /// </summary>
        [Serializable]
        [ProtoContract]
        public class GmBusinessHttp
        {
            [ProtoMember(1)] public string msg = "";

            [ProtoMember(2)] public int code = 0;

            [ProtoMember(3)] public object data;
        }

        /// <summary>
        /// 交易所数据
        /// </summary>
        [Serializable]
        [ProtoContract]
        public class GMBusinessData
        {
            [ProtoMember(1)] public string msg = "";

            [ProtoMember(2)] public int code = 0;
            // 数据列表
            [ProtoMember(3)] public List<GMBusinessDataItem> data = new List<GMBusinessDataItem>();
        }

        /// <summary>
        /// 交易所数据条目
        /// </summary>
        [Serializable]
        [ProtoContract]
        public class GMBusinessDataItem
        {
            // 交易所ID
            [ProtoMember(1)] public int id = 0;

            // 价格
            [ProtoMember(2)] public double price = 0;

            // 货币1
            [ProtoMember(3)] public double purse1 = 0;

            // 货币2
            [ProtoMember(4)] public double purse2 = 0;

            // 手续费
            [ProtoMember(5)] public double charge = 0;

            // 滑点容差
            [ProtoMember(6)] public double deviation = 0;
        }

        /// <summary>
        /// 交易所折线图数据
        /// </summary>
        [Serializable]
        [ProtoContract]
        public class GMBusinessLineData
        {
            [ProtoMember(1)] public string msg = "";

            [ProtoMember(2)] public int code = 0;
            // 数据列表
            [ProtoMember(3)] public List<GMBusinessLineDataItem> data = new List<GMBusinessLineDataItem>();
        }

        /// <summary>
        /// 交易所折线图条目
        /// </summary>
        [Serializable]
        [ProtoContract]
        public class GMBusinessLineDataItem
        {
            // 交易所ID
            [ProtoMember(1)] public int id = 0;

            // 日折线图
            [ProtoMember(2)] public List<GMBUsinessLineDataSingleItem> dayItems = new List<GMBUsinessLineDataSingleItem>();

            // 周折线图
            [ProtoMember(3)] public List<GMBUsinessLineDataSingleItem> weekItems = new List<GMBUsinessLineDataSingleItem>();

            // 月折线图
            [ProtoMember(4)] public List<GMBUsinessLineDataSingleItem> monthItems = new List<GMBUsinessLineDataSingleItem>();

            // 年折线图
            [ProtoMember(5)] public List<GMBUsinessLineDataSingleItem> yearItems = new List<GMBUsinessLineDataSingleItem>();
        }

        /// <summary>
        /// 交易所折线图单一条目
        /// </summary>
        [Serializable]
        [ProtoContract]
        public class GMBUsinessLineDataSingleItem
        {
            // 时间点
            [ProtoMember(1)] public string time = string.Empty;

            // 价格
            [ProtoMember(2)] public double price = 0;
        }

        /// <summary>
        /// 交易所收益记录数据
        /// </summary>
        [Serializable]
        [ProtoContract]
        public class GMBusinessTransEarnData
        {
            [ProtoMember(1)] public string msg = "";

            [ProtoMember(2)] public int code = 0;
            // 数据列表
            [ProtoMember(3)] public List<GMBusinessTransEarnDataItem> data = new List<GMBusinessTransEarnDataItem>();
        }

        /// <summary>
        /// 交易所收益记录数据条目
        /// </summary>
        [Serializable]
        [ProtoContract]
        public class GMBusinessTransEarnDataItem
        {
            // 交易所ID
            [ProtoMember(1)] public int id = 0;

            // 所有的记录
            [ProtoMember(2)] public List<GMBusinessTransEarnDataRecordItem> lstRecords = new List<GMBusinessTransEarnDataRecordItem>();
        }

        /// <summary>
        /// 交易所收益记录数据记录条目
        /// </summary>
        [Serializable]
        [ProtoContract]
        public class GMBusinessTransEarnDataRecordItem
        {
            // 玩家ID
            [ProtoMember(1)] public string userId = "";

            // 玩家所有的记录
            [ProtoMember(2)] public List<GMBusinessTransEarnDataSingleItem> lstItems = new List<GMBusinessTransEarnDataSingleItem>();
        }

        /// <summary>
        /// 交易所收益记录单一条目
        /// </summary>
        [Serializable]
        [ProtoContract]
        public class GMBusinessTransEarnDataSingleItem
        {
            // 货币1
            [ProtoMember(1)] public double purse1 = 0;

            // 货币2
            [ProtoMember(2)] public double purse2 = 0;

            // 时间
            [ProtoMember(3)] public string time = string.Empty;
        }

        /// <summary>
        /// 交易所兑换记录数据
        /// </summary>
        [Serializable]
        [ProtoContract]
        public class GMBusinessExchangeData
        {
            [ProtoMember(1)] public string msg = "";

            [ProtoMember(2)] public int code = 0;
            // 数据列表
            [ProtoMember(3)] public List<GMBusinessExchangeDataItem> data = new List<GMBusinessExchangeDataItem>();
        }

        /// <summary>
        /// 交易所兑换记录数据条目
        /// </summary>
        [Serializable]
        [ProtoContract]
        public class GMBusinessExchangeDataItem
        {
            // 交易所ID
            [ProtoMember(1)] public int id = 0;

            // 所有的记录
            [ProtoMember(2)] public List<GMBusinessExchangeDataRecordItem> lstRecords = new List<GMBusinessExchangeDataRecordItem>();
        }

        /// <summary>
        /// 交易所兑换记录数据记录条目
        /// </summary>
        [Serializable]
        [ProtoContract]
        public class GMBusinessExchangeDataRecordItem
        {
            // 玩家ID
            [ProtoMember(1)] public string userId = "";

            // 玩家所有的记录
            [ProtoMember(2)] public List<GMBusinessExchangeDataSingleItem> lstItems = new List<GMBusinessExchangeDataSingleItem>();
        }

        /// <summary>
        /// 交易所兑换记录单一条目
        /// </summary>
        [Serializable]
        [ProtoContract]
        public class GMBusinessExchangeDataSingleItem
        {
            // 货币1
            [ProtoMember(1)] public double purse1 = 0;

            // 货币2
            [ProtoMember(2)] public double purse2 = 0;

            // 时间
            [ProtoMember(3)] public string time = string.Empty;

            // 兑换方式
            [ProtoMember(4)] public int way = 0;

            // 兑换时的价格
            [ProtoMember(5)] public double price = 0;

            // 手续费
            [ProtoMember(6)] public double charge = 0;

            // 手续费类型
            [ProtoMember(7)] public int chargeType = 0;
        }

        /// <summary>
        /// 交易所交易记录数据
        /// </summary>
        [Serializable]
        [ProtoContract]
        public class GMBusinessTransData
        {
            [ProtoMember(1)] public string msg = "";

            [ProtoMember(2)] public int code = 0;
            // 数据列表
            [ProtoMember(3)] public List<GMBusinessTransDataItem> data = new List<GMBusinessTransDataItem>();
        }

        /// <summary>
        /// 交易所收益记录数据条目
        /// </summary>
        [Serializable]
        [ProtoContract]
        public class GMBusinessTransDataItem
        {
            // 交易所ID
            [ProtoMember(1)] public int id = 0;

            // 所有的记录
            [ProtoMember(2)] public List<GMBusinessTransDataRecordItem> lstRecords = new List<GMBusinessTransDataRecordItem>();
        }

        /// <summary>
        /// 交易所收益记录数据记录条目
        /// </summary>
        [Serializable]
        [ProtoContract]
        public class GMBusinessTransDataRecordItem
        {
            // 玩家ID
            [ProtoMember(1)] public string userId = "";

            // 玩家所有的记录
            [ProtoMember(2)] public List<GMBusinessTransDataSingleItem> lstItems = new List<GMBusinessTransDataSingleItem>();
        }

        /// <summary>
        /// 交易所收益记录单一条目
        /// </summary>
        [Serializable]
        [ProtoContract]
        public class GMBusinessTransDataSingleItem
        {
            // 货币1
            [ProtoMember(1)] public double purse1 = 0;

            // 货币2
            [ProtoMember(2)] public double purse2 = 0;

            // 时间
            [ProtoMember(3)] public string time = string.Empty;

            // 交易方式
            [ProtoMember(4)] public int type = 0;
        }

        /// <summary>
        /// 交易所兑换
        /// </summary>
        [Serializable]
        [ProtoContract]
        public class GMBusinessExchange
        {
            [ProtoMember(1)] public string userId = "";

            [ProtoMember(2)] public int id = 0;

            [ProtoMember(3)] public double purse1 = 0;

            [ProtoMember(4)] public double purse2 = 0;

            [ProtoMember(5)] public int way = 0;

            [ProtoMember(6)] public int major = 0;
        }

        /// <summary>
        /// 交易所兑换返回数据
        /// </summary>
        [Serializable]
        [ProtoContract]
        public class GMExchangeData
        {
            [ProtoMember(1)] public string msg = "";

            [ProtoMember(2)] public int code = 0;

            [ProtoMember(3)] public GMExchangeDataItem data = new GMExchangeDataItem();
        }

        /// <summary>
        /// 交易所兑换返回数据条目
        /// </summary>
        [Serializable]
        [ProtoContract]
        public class GMExchangeDataItem
        {
            // 交易所ID
            [ProtoMember(1)] public int id = 0;

            // 价格
            [ProtoMember(2)] public double price = 0;

            // 货币1
            [ProtoMember(3)] public double purse1 = 0;

            // 货币2
            [ProtoMember(4)] public double purse2 = 0;

            // 时间
            [ProtoMember(5)] public string time = string.Empty;

            // 兑换方式
            [ProtoMember(6)] public int way = 0;

            // 手续费
            [ProtoMember(7)] public double charge = 0;

            // 手续费类型
            [ProtoMember(8)] public int chargeType = 0;

            // 兑换产生的收益列表
            [ProtoMember(9)] public List<GMExchangeTransEarnData> lstEarns = new List<GMExchangeTransEarnData>();

        }

        /// <summary>
        /// 交易所兑换产生的收益数据
        /// </summary>
        [Serializable]
        [ProtoContract]
        public class GMExchangeTransEarnData
        {
            // 玩家ID
            [ProtoMember(1)] public string userId = "";

            // 货币1
            [ProtoMember(2)] public double purse1 = 0;

            // 货币2
            [ProtoMember(3)] public double purse2 = 0;

            // 时间
            [ProtoMember(4)] public string time = string.Empty;
        }

        /// <summary>
        /// 交易所增加交易对
        /// </summary>
        [Serializable]
        [ProtoContract]
        public class GMBusinessAddTransPair
        {
            [ProtoMember(1)] public string userId = "";

            [ProtoMember(2)] public int id = 0;

            [ProtoMember(3)] public double purse1 = 0;

            [ProtoMember(4)] public double purse2 = 0;
        }

        /// <summary>
        /// 交易所增加交易对返回数据
        /// </summary>
        [Serializable]
        [ProtoContract]
        public class GMAddTransPairData
        {
            [ProtoMember(1)] public string msg = "";

            [ProtoMember(2)] public int code = 0;

            [ProtoMember(3)] public GMAddTransPairDataItem data = new GMAddTransPairDataItem();
        }

        /// <summary>
        /// 交易所增加交易对返回数据条目
        /// </summary>
        [Serializable]
        [ProtoContract]
        public class GMAddTransPairDataItem
        {
            // 交易所ID
            [ProtoMember(1)] public int id = 0;

            // 货币1
            [ProtoMember(2)] public double purse1 = 0;

            // 货币2
            [ProtoMember(3)] public double purse2 = 0;

            // 时间
            [ProtoMember(4)] public string time = string.Empty;
        }

        /// <summary>
        /// 交易所减少交易对
        /// </summary>
        [Serializable]
        [ProtoContract]
        public class GMBusinessDelTransPair
        {
            [ProtoMember(1)] public string userId = "";

            [ProtoMember(2)] public int id = 0;

            [ProtoMember(3)] public double purse1 = 0;

            [ProtoMember(4)] public double purse2 = 0;
        }

        /// <summary>
        /// 交易所减少交易对返回数据
        /// </summary>
        [Serializable]
        [ProtoContract]
        public class GMDelTransPairData
        {
            [ProtoMember(1)] public string msg = "";

            [ProtoMember(2)] public int code = 0;

            [ProtoMember(3)] public GMDelTransPairDataItem data = new GMDelTransPairDataItem();
        }

        /// <summary>
        /// 交易所减少交易对返回数据条目
        /// </summary>
        [Serializable]
        [ProtoContract]
        public class GMDelTransPairDataItem
        {
            // 交易所ID
            [ProtoMember(1)] public int id = 0;

            // 货币1
            [ProtoMember(2)] public double purse1 = 0;

            // 货币2
            [ProtoMember(3)] public double purse2 = 0;

            // 时间
            [ProtoMember(4)] public string time = string.Empty;
        }
        #endregion
    }
}